==> oscars_mgmnt_clms-0.1.2.dev20240429+53-py3-none-any.whl: oscars_mgmnt_clms/remove.py <==
import time


class ProductRemoveHelper:
    @staticmethod
    def fix_metadata(doc: dict) -> dict:
        """
        Fixes the metadata to mark the product as removed in OSCARS.
        Changes:
            properties.available: include end date
            properties.updated: update timestamp
            properties.status: updated to CANCELLED
            properties.productInformation.statusDetail: include info message why product is removed
            properties.links: links to product assets are removed

        :param doc: product GeoJSON
        """
        doc = ProductRemoveHelper._fix_dates(doc)
        doc = ProductRemoveHelper._fix_status(doc)
        doc = ProductRemoveHelper._remove_links(doc)
        return doc

    @staticmethod
    def _fix_dates(doc: dict) -> dict:
        """
        Adjust the available date and the updated timestamp.
        """
        now = time.strftime("%Y-%m-%dT%H:%M:%SZ", time.gmtime())
        doc["properties"]["updated"] = now

        date: str = doc["properties"]["available"].split("/")[0]
        date += "/" + now
        doc["properties"]["available"] = date

        return doc

    @staticmethod
    def _fix_status(doc: dict) -> dict:
        """
        Set status to CANCELLED and add info message why product is removed in statusDetail.
        """
        doc["properties"]["status"] = "CANCELLED"
        message = "Product is removed due to Terrascope data retention policy."
        if "productInformation" not in doc["properties"]:
            doc["properties"]["productInformation"] = {}
        doc["properties"]["productInformation"]["statusDetail"] = message

        return doc

    @staticmethod
    def _remove_links(doc: dict) -> dict:
        """
        Clear the links section and leave it empty, as properties.links is a mandatory field by the spec.
        """
        doc["properties"]["links"] = {}
        return doc

==> oscars_mgmnt_clms-0.1.8.dev20240702+100-py3-none-any.whl: oscars_mgmnt_clms/remove.py <==
import time


class ProductRemoveHelper:
    @staticmethod
    def fix_metadata(doc: dict) -> dict:
        """
        Fixes the metadata to mark the product as removed in OSCARS.
        Changes:
            properties.available: include end date
            properties.updated: update timestamp
            properties.status: updated to CANCELLED
            properties.productInformation.statusDetail: include info message why product is removed
            properties.links: links to product assets are removed

        :param doc: product GeoJSON
        """
        doc = ProductRemoveHelper._fix_dates(doc)
        doc = ProductRemoveHelper._fix_status(doc)
        doc = ProductRemoveHelper._remove_links(doc)
        return doc

    @staticmethod
    def _fix_dates(doc: dict) -> dict:
        """
        Adjust the available date and the updated timestamp.
        """
        now = time.strftime("%Y-%m-%dT%H:%M:%SZ", time.gmtime())
        doc["properties"]["updated"] = now

        date: str = doc["properties"]["available"].split("/")[0]
        date += "/" + now
        doc["properties"]["available"] = date

        return doc

    @staticmethod
    def _fix_status(doc: dict) -> dict:
        """
        Set status to CANCELLED and add info message why product is removed in statusDetail.
        """
        doc["properties"]["status"] = "CANCELLED"
        message = "Product is removed due to data retention policy."
        if "productInformation" not in doc["properties"]:
            doc["properties"]["productInformation"] = {}
        doc["properties"]["productInformation"]["statusDetail"] = message

        return doc

    @staticmethod
    def _remove_links(doc: dict) -> dict:
        """
        Clear the links section and leave it empty, as properties.links is a mandatory field by the spec.
        """
        doc["properties"]["links"] = {}
        return doc
